@@ -41,8 +41,8 @@
 #'
 #' @examples
 #' \donttest{
-#' data("dataCar")
-#' fit = hierCredGLM(Y ~ area + (1 | VehicleType / VehicleBody), dataCar, weights = w,
+#' data("tweedietraindata")
+#' fit = hierCredGLM(y ~ x1 + (1 | cluster / subcluster), tweedietraindata, weights = wt,
 #' p = 1.7)
 #' fit
 #' summary(fit)
@@ -88,6 +88,8 @@ hierCredGLM <-
 
     data$Yijkt   = model.extract(glmod$fr, "response")
     data$wijkt   = model.extract(glmod$fr, "weights")
+    if(is.null(data$wijkt))
+      data[, wijkt := rep(1, nrow(data))]
     data$.MLFj    = data[[MLFj]]
     data$.MLFjk   = data[[MLFjk]]
     if(!isNested(data$.MLFjk, data$.MLFj))
@@ -137,15 +139,15 @@ hierCredGLM <-
         if (muHatGLM) {
           eval(
             substitute(
-            hierCredibility(Ytilde, wijkt, MLFj, MLFjk, data, muHat = exp(muHat), type = "multiplicative"),
-            list(MLFj = as.name(MLFj), MLFjk = as.name(MLFjk))
-          ))
+              hierCredibility(Ytilde, wtilde, MLFj, MLFjk, data, muHat = exp(muHat), type = "multiplicative"),
+              list(MLFj = as.name(MLFj), MLFjk = as.name(MLFjk))
+            ))
         } else {
           eval(
             substitute(
-            hierCredibility(Ytilde, wijkt, MLFj, MLFjk, data, type = "multiplicative"),
-            list(MLFj = as.name(MLFj), MLFjk = as.name(MLFjk))
-          ))
+              hierCredibility(Ytilde, wtilde, MLFj, MLFjk, data, type = "multiplicative"),
+              list(MLFj = as.name(MLFj), MLFjk = as.name(MLFjk))
+            ))
         }
       data[, `:=` (
         Uj  = Jewell$Relativity$sector$Uj[match(.MLFj, Jewell$Relativity$sector[[MLFj]])],
@@ -173,7 +175,7 @@ hierCredGLM <-
     if(iter > maxiter)
       warning("Maximum number of iterations reached.", immediate. = T)
     fitGLM = glm(FormulaGLM, data = data, weights = data$wijkt, family = tweedie(var.power = p, link.power = 0),
-                 y = T, model = T, ...)
+                 y = TRUE, model = TRUE, ...)
     fitGLM$prior.weights = data$wijkt
     if(balanceProperty)
       fitGLM = adjustIntercept(fitGLM, data = data)
@@ -195,7 +197,7 @@ hierCredGLM <-
            fitted.values = fitted,
            prior.weights = fitGLM$prior.weights,
            y = if(y) fitGLM$y else NULL
-           ),
+      ),
       class = "hierCredGLM")
     if(returnData)
       Results$data = data
@@ -242,17 +244,16 @@ hierCredGLM <-
 #'
 #' @details When estimating the GLM part, this function uses the \code{\link[cplm]{cpglm}} function from the \code{cplm} package.
 #'
-#' @seealso \code{\link{hierCredTweedie-class}}, \code{\link{fitted.hierCredTweedie}}, \code{\link{predict.hierCredTweedie}}, \code{\link{ranef-actuaRE}},
-#'  \code{\link{weights-actuaRE}}, \code{\link{hierCredibility}}, \code{\link{hierCredGLM}}, \code{\link[cplm]{cpglm}}, \code{\link{plotRE}},
-#'  \code{\link{adjustIntercept}}, \code{\link{BalanceProperty}}
-#'  @references   Campo, B.D.C. and Antonio, Katrien (2023). Insurance pricing with hierarchically structured data an illustration with a workers' compensation insurance portfolio. \emph{Scandinavian Actuarial Journal}, doi: 10.1080/03461238.2022.2161413
+#' @seealso \code{\link{hierCredTweedie-class}}, \code{\link{hierCredibility}}, \code{\link{hierCredGLM}}, \code{\link[cplm]{cpglm}},
+#' \code{\link{plotRE}}, \code{\link{adjustIntercept}}, \code{\link{BalanceProperty}}
+#' @references Campo, B.D.C. and Antonio, Katrien (2023). Insurance pricing with hierarchically structured data an illustration with a workers' compensation insurance portfolio. \emph{Scandinavian Actuarial Journal}, doi: 10.1080/03461238.2022.2161413
 #' @references Ohlsson, E. (2008). Combining generalized linear models and credibility models in practice. \emph{Scandinavian Actuarial Journal} \bold{2008}(4), 301–314.
 #'
 #' @examples
 #' \donttest{
-#' data("dataCar")
-#' fit = hierCredTweedie(Y ~ area + (1 | VehicleType / VehicleBody), dataCar,
-#' weights = w, epsilon = 1e-6)
+#' data("tweedietraindata")
+#' fit = hierCredTweedie(y ~ x1 + (1 | cluster / subcluster), tweedietraindata, weights = wt,
+#' p = 1.7)
 #' fit
 #' summary(fit)
 #' ranef(fit)
@@ -293,6 +294,8 @@ hierCredTweedie <-
 
     data$Yijkt   = model.extract(glmod$fr, "response")
     data$wijkt   = model.extract(glmod$fr, "weights")
+    if(is.null(data$wijkt))
+      data[, wijkt := rep(1, nrow(data))]
     data$.MLFj    = data[[MLFj]]
     data$.MLFjk   = data[[MLFjk]]
     if(!isNested(data$.MLFjk, data$.MLFj))
@@ -347,13 +350,13 @@ hierCredTweedie <-
         if (muHatGLM) {
           eval(
             substitute(
-              hierCredibility(Ytilde, wijkt, MLFj, MLFjk, data, muHat = exp(muHat), type = "multiplicative"),
+              hierCredibility(Ytilde, wtilde, MLFj, MLFjk, data, muHat = exp(muHat), type = "multiplicative"),
               list(MLFj = as.name(MLFj), MLFjk = as.name(MLFjk))
             ))
         } else {
           eval(
             substitute(
-              hierCredibility(Ytilde, wijkt, MLFj, MLFjk, data, type = "multiplicative"),
+              hierCredibility(Ytilde, wtilde, MLFj, MLFjk, data, type = "multiplicative"),
               list(MLFj = as.name(MLFj), MLFjk = as.name(MLFjk))
             ))
         }
